.. note::

    Some attributes may not be available from older qBittorrent version.
    ``AttributeError`` may  raise when accessing these attributes.

    Use `try-except` block or ``getattr()`` to handle these cases.